#[repr(u8)]pub enum Color {
White = 0,
Black = 1,
}Expand description
Color of chess pieces (either white or black)
Variants
Implementations
Sourceimpl Color
impl Color
Sourcepub fn as_char(&self) -> char
pub fn as_char(&self) -> char
Returns a character representation of the color
The character representation is "w" for white, and "b" for black.
Sourcepub fn from_char(c: char) -> Option<Color>
pub fn from_char(c: char) -> Option<Color>
Creates a color from its character representation
If c is not a valid character representation of color, returns None.
Sourcepub fn as_long_str(&self) -> &'static str
pub fn as_long_str(&self) -> &'static str
Returns a full string representation of the color (either "white" or "black")