Cell

Struct Cell 

pub struct Cell(/* private fields */);
Contents of square on a chess board

A square can be either empty or contain a piece of some given color.

This type is one compact and is only one byte long to facilitate compact chess board representation.

Implementations

Source

impl Cell

pub const EMPTY: Cell

Cell without any pieces

pub const COUNT: usize = 13

Number of different possible indices of Cell

It exceeds maximum possible index by one.

pub const fn is_free(&self) -> bool

Returns true if the cell doesn’t contain any pieces

pub const fn is_occupied(&self) -> bool

Returns true if the cell contains a piece

pub const unsafe fn from_index_unchecked(val: usize) -> Cell

Creates a cell from its index

Safety

The behavior is undefined if the index is invalid (i.e. it is greater or equal than Cell::COUNT)

pub const fn from_index(val: usize) -> Cell

Creates a cell from its index

Panics

The function panics if the index is invalid (i.e. it is greater or equal than Cell::COUNT)

pub const fn index(&self) -> usize

Returns the index of the cell

Cell indices are stable between updates, and changing the index of some given cell is considered API breakage.

pub const fn from_parts(c: Color, p: Piece) -> Cell

Creates a cell with a piece p of color c

pub const fn color(&self) -> Option<Color>

Returns the color of the piece on the cell

If the cell is empty, returns None.

pub const fn piece(&self) -> Option<Piece>

Returns the kind of the piece on the cell

If the cell is empty, returns None.

pub fn iter() -> impl Iterator<Item = Cell>

Iterates over all possible cells in ascending order of their indices

pub fn as_char(&self) -> char

Returns a character representation of the cell

Unlike Cell::as_utf8_char, the representation is an ASCII character.

pub fn as_utf8_char(&self) -> char

Converts a cell to a corresponding Unicode character

pub fn from_char(c: char) -> Option<Cell>

Creates a cell from its character representation

If c is not a valid character representation of a cell, returns None. Note that only ASCII character repesentations as returned by Cell::as_char are accepted.